@@ -7,7 +7,7 @@ import pathlib
 import subprocess
 from chinstrap import helpers
 from prompt_toolkit import HTML
-from chinstrap.helpers import startSpinner
+from chinstrap.helpers import hexit, startSpinner
 from chinstrap.helpers import checkToCreateDir
 from chinstrap.core.templates import contracts
 from chinstrap.helpers import ensurePathExists
@@ -41,11 +41,6 @@ class SmartPy:
 
         return fullPath
 
-    def printSmartPyVersion(self):
-        proc = runCommand(f"{self.compiler} --version", shell=True)
-        proc.wait()
-        print(proc.stdout.read().decode())
-
     def compileSources(self):
         contracts = glob.iglob("contracts/*.py")
         self.initBuildFolder()
@@ -98,7 +93,6 @@ class SmartPy:
         Compile with local SmartPy-cli
         """
         self.compiler = self.getCompiler()
-        self.printSmartPyVersion()
 
         command = [self.compiler, "compile", str(contract), "./build/contracts/"]
         proc = subprocess.Popen(command, stdout=subprocess.PIPE, stderr=subprocess.PIPE)
@@ -209,28 +203,21 @@ class SmartPy:
         helpers.mkdir("./build/contracts/")
 
     @staticmethod
-    def installCompiler(local=False, force=False, spin=None):
+    def installCompiler(local=False, force=False):
+        spin = startSpinner("Installing SmartPy")
+
         if local:
             fullPath = os.path.expanduser("~/chinstrap/bin")
-            create = True
-            if os.path.exists(fullPath):
-                if spin:
-                    spin.stop()
+            
+            os.makedirs(fullPath, exist_ok=True)
 
-                if not checkToCreateDir(fullPath, force):
-                    create = False
-
-            if create:
-                os.makedirs(fullPath)
-
-            spin = startSpinner("Installing SmartPy")
             ensurePathExists(fullPath)
 
             cmds = [
-                "curl -o /tmp/chinstrap-smartpy-install.sh -L https://smartpy.io/cli/install.sh",
-                "chmod +x /tmp/chinstrap-smartpy-install.sh",
-                "/tmp/chinstrap-smartpy-install.sh --prefix \
-                        ~/chinstrap/bin/smartpy-cli --with-smartml --yes",
+                "curl -o ~/chinstrap/bin/smartpy-install.sh -L https://smartpy.io/cli/install.sh",
+                "chmod +x ~/chinstrap/bin/smartpy-install.sh",
+                "~/chinstrap/bin/smartpy-install.sh --prefix \
+                        ~/chinstrap/bin/smartpy-cli",
                 '/bin/bash -c "chmod +x ~/chinstrap/bin/smartpy-cli/SmartPy.sh"',
             ]
 
@@ -238,14 +225,15 @@ class SmartPy:
                 proc = runCommand(cmd, shell=True)
                 proc.wait()
 
-            os.remove("/tmp/chinstrap-smartpy-install.sh")
-            return spin
+            os.remove(f"{fullPath}/smartpy-install.sh")
+    
         else:
             suc, msg = pullImage(image, "latest")
             if not suc:
                 spin.fail(f"Failed to install compiler. {msg}")
-                return
-            return spin
+                hexit(1)
+            
+        spin.stop_and_persist("🎉", "SmartPy installed")
 
     @staticmethod
     def templates():
